# github作为图床

import os
import sys
import click

from easy_toolkit.default_settings import SettingsHandler
from easy_toolkit.utils import urljoin, is_image

from github import Github

@click.command(name="gitpic")
@click.option('-f', '--file', required=True,  help='Your pic path')
@click.option('-m', '--message', default="",  help='commit message')
@click.option('-n', '--name', default="",  help='Picture name')
def hello(file, message, name):
    if not os.path.exists(file):
        click.echo(click.style("File [{}] not exists", fg="red").format(file))
        sys.exit(1)
    if not is_image(file):
        click.echo(click.style("Please choose a image type file!", fg="red"))
        sys.exit(1)
    if not name:
        name = os.path.basename(file)
    if not message:
        message = "add picture {}".format(name)

    raw_base_url = r"https://raw.githubusercontent.com/"
    repo_branch = "master"

    # using username and password
    github_token = SettingsHandler.read_property("github_token")
    if not github_token:
        github_username, github_password = SettingsHandler.read_property("github_username"), SettingsHandler.read_property("github_password")
        if not all([github_username, github_password]):
            click.echo(click.style("Please set [github_token] or [github_username、github_password] before use gitpic!", fg="red"))
            sys.exit(1)
        else:
            g = Github(github_username, github_password)
    else:
        g = Github(github_token)

    # repo_name = "fadeawaylove/article-images"
    repo_name = SettingsHandler.read_property("github_reponame")
    if repo_name is None:
        click.echo(click.style("Please set [github_reponame] before use gitpic!", fg="red"))
        sys.exit(1)
    # Then play with your Github objects:
    picture_repo = g.get_repo(repo_name)

    file_name = name
    file_path = file
    try:
        ret = picture_repo.create_file(path=file_name, message=message, content=open(file_path, 'rb').read(), branch="master")["content"]
    except Exception as e:
        if e.status == 422:
            # 文件名 已经存在 返回存在文件的路径
            click.echo(click.style("file [{}] already exists!", fg="red").format(name), )
            ret = picture_repo.get_contents(name)
            file_raw_url = urljoin(raw_base_url, repo_name, repo_branch, ret.path)
            click.echo("raw path ==> {}".format(file_raw_url))
        else:
            click.echo(e)
        sys.exit(1)
        
    file_raw_url = urljoin(raw_base_url, repo_name, repo_branch, ret.path)
    click.echo("upload success ==> {}".format(file_raw_url))
    return file_raw_url


import os
import json

from .utils import get_home_path


class SettingsHandler(object):
    
    config_dir = os.path.join(get_home_path(), ".easy_tools")
    config_file_name = "config.json"
    config_file_path = os.path.join(config_dir, config_file_name)
    os.makedirs(config_dir, exist_ok=True)
    if not os.path.exists(config_file_path):
        with open(config_file_path, "wb") as ff:
            ff.write(b"{}")
    with open(config_file_path, "r") as fr:
        content = fr.read()
        if not content:
            settings_json = {}
        else:
            settings_json = json.loads(content)

    @classmethod
    def read_property(cls, pro_path):
        temp = cls.settings_json
        for p in pro_path.split("."):
            temp = temp.get(p)
            if temp is None:
                # print("Maybe property path not exists! [{}]".format(pro_path))
                return temp
        return temp











import os
from setuptools import setup, find_packages

md_path =os.path.join(os.path.dirname(os.path.abspath(__file__)), "README.md")

setup(
    name='easy_toolkit',
    version='0.1.4',
    author="呆瓜",
    author_email="1032939141@qq.com",
    long_description=open(md_path, encoding='utf-8').read(),
    long_description_content_type='text/markdown',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'Click',
        'PyGithub>=1.51'
    ],
    entry_points='''
        [console_scripts]
        easytool=easy_toolkit.entry:entry
    ''',
    url="https://gitee.com/fadeaway_dai/convenient_toolkit"
)

# python setup.py sdist
# twine upload dist/*version*


import os
import imghdr
from urllib import parse
from posixpath import normpath


def get_home_path():
    return os.path.expanduser("~")


def urljoin(base, *url_paths):
<<<<<<< HEAD
    url_path = parse.quote("/".join(url_paths))
    return parse.urljoin(base, normpath(url_path))
=======
    url_path = "/".join(url_paths)
    return parse.quote(normpath(parse.urljoin(base, url_path)))
>>>>>>> 10850f7efb1f12410d59a92aa598350308d8c4ac


def is_image(file_path):
    ret = imghdr.what(file_path)
    return False if ret is None else True



import importlib
from click.core import Command
import click
import os

# all command entries
@click.group()
def entry():
    pass


# scan all functions in the package toolkit and find out the type of "command", then import these functions
base_tools_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), "toolkit")
base_module_name = "easy_toolkit.toolkit"


def scan_all_command(parent_path, module_name):
    ret = []
    for child in os.listdir(parent_path):
        if child.startswith("__"):
            continue
        if os.path.isdir(os.path.join(parent_path, child)):
            ret.extend(scan_all_command(os.path.join(
                parent_path, child), ".".join([module_name, child])))
        else:
            if not child.endswith(".py"):
                continue
            ret.append(".".join([module_name, child])[:-3])
    return ret


r = scan_all_command(base_tools_path, base_module_name)

all_packages = [importlib.import_module(x) for x in r]
for x in all_packages:
    for d in dir(x):
        if d.startswith("__"):
            continue
        f_obj = getattr(x, d)
        if isinstance(f_obj, click.core.Command):
            entry.add_command(f_obj)


if __name__ == '__main__':
    entry()
